registeredWithType property
Type
get
registeredWithType
the type that was used when registering, used for runtime checks
Implementation
Type get registeredWithType;
the type that was used when registering, used for runtime checks
Type get registeredWithType;