di top-level property

GetIt di
final

WatchIt exports the default instance of get_it as a global variable which lets you access it from anywhere in your app. To access any get_it registered object you only have to type di<MyType>() instead of GetIt.I<MyType>(). if you don't want to use a different instance of get_it you can pass it to the functions of this library as an optional parameter

Implementation

final di = GetIt.I;